<template>
    <!-- Formulario para calcular costo del envio -->
    <div class="block-calculate-shipping">
        <div class="title-calculate-shipping">
            <span>Calcular envío</span>
            <div v-if="isLoadingShipping" class="spinner-inline"></div>
        </div>
        <form @submit.prevent>
            <div class="form-group">
                <input
                    v-model="postalCode"
                    type="text"
                    placeholder="Código postal"
                    class="form-control"
                    @keydown.enter.prevent
                />
            </div>
        </form>
    </div>
    <div v-if="!isValidPostalCode" class="mtm-15">
        <p class="error-message">Código postal no válido</p>
    </div>
    <div class="mt10">
        <p>Opciones de envío disponibles acorde a su código postal</p>
    </div>
    <!-- Formulario para calcular costo del envio -->
    <!-- Selección de Recogida Local (Siempre Visible) -->
    <label class="label-shipping-method">
        <input v-model="selectedShippingMethod" type="radio" value="local_pickup" @change="validateForm" />
        <div class="title-shipping-method">Retiro personalmente en <span>JUSTICIALISTAS</span></div>
        <div class="subtitle-shipping-method">Jose Antonio Guardado 50, Córdoba</div>
    </label>
    <!-- Selección de Recogida Local (Siempre Visible) -->

    <!-- Opciones de Envío adicionales (mantiene los radios visibles tras Calcular) -->
    <div class="block-shipping-oca">
        <!-- Retiro en Sucursal -->
        <label class="label-shipping-oca">
            <input
                v-model="selectedShippingMethod"
                type="radio"
                value="branch_pickup"
                :disabled="!store.isShippingCalculated"
                @change="validateForm"
            />
            <div class="title-shipping-oca">Retiro en Sucursal</div>
        </label>
        <select
            v-if="selectedShippingMethod === 'branch_pickup'"
            v-model="selectedBranch"
            class="form-select select-shipping-oca"
            @change="validateForm"
        >
            <option v-for="branch in store.branches" :key="branch.IdCentroImposicion" :value="branch">
                {{ branch.Sucursal }}<span> ({{ branch.Calle }} {{ branch.Numero }})</span>
            </option>
        </select>

        <!-- Envío a Domicilio -->
        <label class="label-shipping-oca">
            <input
                v-model="selectedShippingMethod"
                type="radio"
                value="home_delivery"
                :disabled="!store.isShippingCalculated"
                @change="validateForm"
            />
            <div class="title-shipping-oca">Envío a Domicilio Particular</div>
        </label>
    </div>
</template>

<script setup>
import { ref, watch, onMounted, defineProps, defineEmits } from "vue";
import { cartStore } from "../../../js/stores/cart.js";
import { useShippingStore } from "../../../js/stores/shippingStore.js";
import { debounce } from "lodash";

const props = defineProps({
    showAddressForm: {
        type: Boolean,
        default: true,
    },
});

const showOcaOptions = ref(false);
const showCalculationForm = ref(false);
const store = cartStore();
const shippingStore = useShippingStore();
const selectedShippingMethod = ref(store.selectedShippingMethod);
const selectedBranch = ref(store.selectedBranch);
const selectedProvince = ref(store.selectedProvince);
const selectedCity = ref(store.selectedCity);
const postalCode = ref(store.billingPostalCode);
const branches = ref(store.branches);
const emit = defineEmits(["validate"]);
const isShippingCalculated = ref(store.isShippingCalculated);

const isLoadingShipping = ref(false);
const isValidPostalCode = ref(true);

watch(
    postalCode,
    debounce(async (newCode) => {
        if (!newCode || newCode.trim().length < 4 || !/^\d+$/.test(newCode.trim())) return;

        if (store.items.length < 1) {
            store.updateDoorToDoorCost(0);
            store.updateDoorToBranchCost(0);
            store.updateShippingCost(0);
            store.updateBranches([]);

            return;
        }

        isLoadingShipping.value = true; // ⏳ empieza el loading
        isValidPostalCode.value = await shippingStore.calculateShipping(newCode);
        isLoadingShipping.value = false; // ✅ termina el loading
        if (isValidPostalCode.value) {
            showOcaOptions.value = true;
            showCalculationForm.value = false;
            store.updateShippingCalculated(true);
        } else {
            store.updateDoorToDoorCost(0);
            store.updateDoorToBranchCost(0);
            store.updateShippingCost(0);
            store.updateBranches([]);
            store.updateShippingCalculated(false);
            showOcaOptions.value = false;
            showCalculationForm.value = true;
        }
    }, 600),
); // espera 600ms después del último cambio

const validateForm = () => {
    let isValid = true;

    if (selectedShippingMethod.value === "branch_pickup" && !selectedBranch.value) {
        isValid = false;
    }

    emit("validate", isValid);
};

watch([selectedShippingMethod, selectedBranch], validateForm);
watch(selectedShippingMethod, (value) => store.updateShippingMethod(value));
watch(selectedBranch, (value) => store.updateBranch(value));
watch(selectedProvince, (value) => store.updateProvince(value));
watch(selectedCity, (value) => store.updateCity(value));
watch(postalCode, (value) => store.updateBillingPostalCode(value));
watch(branches, (value) => store.updateBranches(value));
watch(isShippingCalculated, (value) => store.isShippingCalculated(value));

onMounted(() => {
    validateForm();

    if (postalCode.value === null || postalCode.value === "") {
        showOcaOptions.value = false;
        showCalculationForm.value = true;
    } else {
        showOcaOptions.value = true;
        showCalculationForm.value = false;
    }
});
</script>

<style scoped>
.accordion-item {
    border: none;
}

.label-shipping-method {
    display: ruby;

    .title-shipping-method {
        margin-left: 18px;

        span {
            font-weight: 700;
            text-transform: uppercase;
        }
    }

    .subtitle-shipping-method {
        margin-left: 30px;
    }
}

.block-shipping-oca {
    display: grid;

    .label-shipping-oca {
        display: ruby;
        margin-top: 10px;

        .title-shipping-oca {
            margin-left: 18px;
        }
    }
}

.block-calculate-shipping {
    margin-top: -20px;

    .form-select {
        margin-bottom: 10px;
    }
}

.select-shipping-oca {
    margin-left: 29px;
}

.title-calculate-shipping {
    display: flex;
    align-items: center;
    gap: 8px;
    font-weight: 600;
    margin-bottom: 8px;
}

.spinner-inline {
    width: 16px;
    height: 16px;
    border: 3px solid rgb(0 0 0 / 10%);
    border-left-color: #09f;
    border-radius: 50%;
    animation: spin 0.8s linear infinite;
}

@keyframes spin {
    to {
        transform: rotate(360deg);
    }
}
</style>
